==> google_cloud_securitycenter-1.31.0-py2.py3-none-any.whl: google/cloud/securitycenter_v2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .access import Access, Geolocation, ServiceAccountDelegationInfo
from .application import Application
from .attack_exposure import AttackExposure
from .attack_path import AttackPath
from .backup_disaster_recovery import BackupDisasterRecovery
from .bigquery_export import BigQueryExport
from .cloud_dlp_data_profile import CloudDlpDataProfile
from .cloud_dlp_inspection import CloudDlpInspection
from .compliance import Compliance
from .connection import Connection
from .contact_details import Contact, ContactDetails
from .container import Container
from .database import Database
from .exfiltration import ExfilResource, Exfiltration
from .external_system import ExternalSystem
from .file import File
from .finding import Finding
from .iam_binding import IamBinding
from .indicator import Indicator
from .kernel_rootkit import KernelRootkit
from .kubernetes import Kubernetes
from .label import Label
from .load_balancer import LoadBalancer
from .log_entry import CloudLoggingEntry, LogEntry
from .mitre_attack import MitreAttack
from .mute_config import MuteConfig
from .notification_config import NotificationConfig
from .notification_message import NotificationMessage
from .org_policy import OrgPolicy
from .process import EnvironmentVariable, Process
from .resource import Resource
from .resource_value_config import ResourceValue, ResourceValueConfig
from .security_marks import SecurityMarks
from .security_posture import SecurityPosture
from .securitycenter_service import (
    BatchCreateResourceValueConfigsRequest,
    BatchCreateResourceValueConfigsResponse,
    BulkMuteFindingsRequest,
    BulkMuteFindingsResponse,
    CreateBigQueryExportRequest,
    CreateFindingRequest,
    CreateMuteConfigRequest,
    CreateNotificationConfigRequest,
    CreateResourceValueConfigRequest,
    CreateSourceRequest,
    DeleteBigQueryExportRequest,
    DeleteMuteConfigRequest,
    DeleteNotificationConfigRequest,
    DeleteResourceValueConfigRequest,
    GetBigQueryExportRequest,
    GetMuteConfigRequest,
    GetNotificationConfigRequest,
    GetResourceValueConfigRequest,
    GetSimulationRequest,
    GetSourceRequest,
    GetValuedResourceRequest,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAttackPathsRequest,
    ListAttackPathsResponse,
    ListBigQueryExportsRequest,
    ListBigQueryExportsResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListMuteConfigsRequest,
    ListMuteConfigsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListResourceValueConfigsRequest,
    ListResourceValueConfigsResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    ListValuedResourcesRequest,
    ListValuedResourcesResponse,
    SetFindingStateRequest,
    SetMuteRequest,
    UpdateBigQueryExportRequest,
    UpdateExternalSystemRequest,
    UpdateFindingRequest,
    UpdateMuteConfigRequest,
    UpdateNotificationConfigRequest,
    UpdateResourceValueConfigRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from .simulation import Simulation
from .source import Source
from .valued_resource import ResourceValueConfigMetadata, ValuedResource
from .vulnerability import (
    Cve,
    Cvssv3,
    Package,
    Reference,
    SecurityBulletin,
    Vulnerability,
)

__all__ = (
    "Access",
    "Geolocation",
    "ServiceAccountDelegationInfo",
    "Application",
    "AttackExposure",
    "AttackPath",
    "BackupDisasterRecovery",
    "BigQueryExport",
    "CloudDlpDataProfile",
    "CloudDlpInspection",
    "Compliance",
    "Connection",
    "Contact",
    "ContactDetails",
    "Container",
    "Database",
    "ExfilResource",
    "Exfiltration",
    "ExternalSystem",
    "File",
    "Finding",
    "IamBinding",
    "Indicator",
    "KernelRootkit",
    "Kubernetes",
    "Label",
    "LoadBalancer",
    "CloudLoggingEntry",
    "LogEntry",
    "MitreAttack",
    "MuteConfig",
    "NotificationConfig",
    "NotificationMessage",
    "OrgPolicy",
    "EnvironmentVariable",
    "Process",
    "Resource",
    "ResourceValueConfig",
    "ResourceValue",
    "SecurityMarks",
    "SecurityPosture",
    "BatchCreateResourceValueConfigsRequest",
    "BatchCreateResourceValueConfigsResponse",
    "BulkMuteFindingsRequest",
    "BulkMuteFindingsResponse",
    "CreateBigQueryExportRequest",
    "CreateFindingRequest",
    "CreateMuteConfigRequest",
    "CreateNotificationConfigRequest",
    "CreateResourceValueConfigRequest",
    "CreateSourceRequest",
    "DeleteBigQueryExportRequest",
    "DeleteMuteConfigRequest",
    "DeleteNotificationConfigRequest",
    "DeleteResourceValueConfigRequest",
    "GetBigQueryExportRequest",
    "GetMuteConfigRequest",
    "GetNotificationConfigRequest",
    "GetResourceValueConfigRequest",
    "GetSimulationRequest",
    "GetSourceRequest",
    "GetValuedResourceRequest",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupResult",
    "ListAttackPathsRequest",
    "ListAttackPathsResponse",
    "ListBigQueryExportsRequest",
    "ListBigQueryExportsResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListMuteConfigsRequest",
    "ListMuteConfigsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListResourceValueConfigsRequest",
    "ListResourceValueConfigsResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "ListValuedResourcesRequest",
    "ListValuedResourcesResponse",
    "SetFindingStateRequest",
    "SetMuteRequest",
    "UpdateBigQueryExportRequest",
    "UpdateExternalSystemRequest",
    "UpdateFindingRequest",
    "UpdateMuteConfigRequest",
    "UpdateNotificationConfigRequest",
    "UpdateResourceValueConfigRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
    "Simulation",
    "Source",
    "ResourceValueConfigMetadata",
    "ValuedResource",
    "Cve",
    "Cvssv3",
    "Package",
    "Reference",
    "SecurityBulletin",
    "Vulnerability",
)

==> google_cloud_securitycenter-1.38.0-py2.py3-none-any.whl: google/cloud/securitycenter_v2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .access import Access, Geolocation, ServiceAccountDelegationInfo
from .application import Application
from .attack_exposure import AttackExposure
from .attack_path import AttackPath
from .backup_disaster_recovery import BackupDisasterRecovery
from .bigquery_export import BigQueryExport
from .cloud_armor import (
    AdaptiveProtection,
    Attack,
    CloudArmor,
    Requests,
    SecurityPolicy,
)
from .cloud_dlp_data_profile import CloudDlpDataProfile
from .cloud_dlp_inspection import CloudDlpInspection
from .compliance import Compliance
from .connection import Connection
from .contact_details import Contact, ContactDetails
from .container import Container
from .data_access_event import DataAccessEvent
from .data_flow_event import DataFlowEvent
from .data_retention_deletion_event import DataRetentionDeletionEvent
from .database import Database
from .disk import Disk
from .exfiltration import ExfilResource, Exfiltration
from .external_system import ExternalSystem
from .file import File
from .finding import Finding
from .folder import Folder
from .group_membership import GroupMembership
from .iam_binding import IamBinding
from .indicator import Indicator
from .kernel_rootkit import KernelRootkit
from .kubernetes import Kubernetes
from .label import Label
from .load_balancer import LoadBalancer
from .log_entry import CloudLoggingEntry, LogEntry
from .mitre_attack import MitreAttack
from .mute_config import MuteConfig
from .notebook import Notebook
from .notification_config import NotificationConfig
from .notification_message import NotificationMessage
from .org_policy import OrgPolicy
from .process import EnvironmentVariable, Process
from .resource import (
    AwsMetadata,
    AzureMetadata,
    CloudProvider,
    GcpMetadata,
    Resource,
    ResourcePath,
)
from .resource_value_config import ResourceValue, ResourceValueConfig
from .security_marks import SecurityMarks
from .security_posture import SecurityPosture
from .securitycenter_service import (
    BatchCreateResourceValueConfigsRequest,
    BatchCreateResourceValueConfigsResponse,
    BulkMuteFindingsRequest,
    BulkMuteFindingsResponse,
    CreateBigQueryExportRequest,
    CreateFindingRequest,
    CreateMuteConfigRequest,
    CreateNotificationConfigRequest,
    CreateResourceValueConfigRequest,
    CreateSourceRequest,
    DeleteBigQueryExportRequest,
    DeleteMuteConfigRequest,
    DeleteNotificationConfigRequest,
    DeleteResourceValueConfigRequest,
    GetBigQueryExportRequest,
    GetMuteConfigRequest,
    GetNotificationConfigRequest,
    GetResourceValueConfigRequest,
    GetSimulationRequest,
    GetSourceRequest,
    GetValuedResourceRequest,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAttackPathsRequest,
    ListAttackPathsResponse,
    ListBigQueryExportsRequest,
    ListBigQueryExportsResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListMuteConfigsRequest,
    ListMuteConfigsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListResourceValueConfigsRequest,
    ListResourceValueConfigsResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    ListValuedResourcesRequest,
    ListValuedResourcesResponse,
    SetFindingStateRequest,
    SetMuteRequest,
    UpdateBigQueryExportRequest,
    UpdateExternalSystemRequest,
    UpdateFindingRequest,
    UpdateMuteConfigRequest,
    UpdateNotificationConfigRequest,
    UpdateResourceValueConfigRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from .simulation import Simulation
from .source import Source
from .toxic_combination import ToxicCombination
from .valued_resource import ResourceValueConfigMetadata, ValuedResource
from .vulnerability import (
    Cve,
    Cvssv3,
    Package,
    Reference,
    SecurityBulletin,
    Vulnerability,
)

__all__ = (
    "Access",
    "Geolocation",
    "ServiceAccountDelegationInfo",
    "Application",
    "AttackExposure",
    "AttackPath",
    "BackupDisasterRecovery",
    "BigQueryExport",
    "AdaptiveProtection",
    "Attack",
    "CloudArmor",
    "Requests",
    "SecurityPolicy",
    "CloudDlpDataProfile",
    "CloudDlpInspection",
    "Compliance",
    "Connection",
    "Contact",
    "ContactDetails",
    "Container",
    "DataAccessEvent",
    "DataFlowEvent",
    "DataRetentionDeletionEvent",
    "Database",
    "Disk",
    "ExfilResource",
    "Exfiltration",
    "ExternalSystem",
    "File",
    "Finding",
    "Folder",
    "GroupMembership",
    "IamBinding",
    "Indicator",
    "KernelRootkit",
    "Kubernetes",
    "Label",
    "LoadBalancer",
    "CloudLoggingEntry",
    "LogEntry",
    "MitreAttack",
    "MuteConfig",
    "Notebook",
    "NotificationConfig",
    "NotificationMessage",
    "OrgPolicy",
    "EnvironmentVariable",
    "Process",
    "AwsMetadata",
    "AzureMetadata",
    "GcpMetadata",
    "Resource",
    "ResourcePath",
    "CloudProvider",
    "ResourceValueConfig",
    "ResourceValue",
    "SecurityMarks",
    "SecurityPosture",
    "BatchCreateResourceValueConfigsRequest",
    "BatchCreateResourceValueConfigsResponse",
    "BulkMuteFindingsRequest",
    "BulkMuteFindingsResponse",
    "CreateBigQueryExportRequest",
    "CreateFindingRequest",
    "CreateMuteConfigRequest",
    "CreateNotificationConfigRequest",
    "CreateResourceValueConfigRequest",
    "CreateSourceRequest",
    "DeleteBigQueryExportRequest",
    "DeleteMuteConfigRequest",
    "DeleteNotificationConfigRequest",
    "DeleteResourceValueConfigRequest",
    "GetBigQueryExportRequest",
    "GetMuteConfigRequest",
    "GetNotificationConfigRequest",
    "GetResourceValueConfigRequest",
    "GetSimulationRequest",
    "GetSourceRequest",
    "GetValuedResourceRequest",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupResult",
    "ListAttackPathsRequest",
    "ListAttackPathsResponse",
    "ListBigQueryExportsRequest",
    "ListBigQueryExportsResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListMuteConfigsRequest",
    "ListMuteConfigsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListResourceValueConfigsRequest",
    "ListResourceValueConfigsResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "ListValuedResourcesRequest",
    "ListValuedResourcesResponse",
    "SetFindingStateRequest",
    "SetMuteRequest",
    "UpdateBigQueryExportRequest",
    "UpdateExternalSystemRequest",
    "UpdateFindingRequest",
    "UpdateMuteConfigRequest",
    "UpdateNotificationConfigRequest",
    "UpdateResourceValueConfigRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
    "Simulation",
    "Source",
    "ToxicCombination",
    "ResourceValueConfigMetadata",
    "ValuedResource",
    "Cve",
    "Cvssv3",
    "Package",
    "Reference",
    "SecurityBulletin",
    "Vulnerability",
)
